@@ -7,14 +7,14 @@ from tw.forms import TableForm, SingleSelectField, FormField, TextField
 from tw.dynforms import OtherSingleSelectField, HidingContainerMixin, HidingSingleSelectField
 from formencode import validators
 
-from tg import expose, flash, require, url, request, redirect, session, TGController
+from tg import expose, flash, require, url, request, redirect, session, TGController, config
 from pylons.i18n import ugettext as _, lazy_ugettext as l_
 from tgext.admin.tgadminconfig import TGAdminConfig
 from tgext.admin.controller import AdminController
 from repoze.what import predicates
 from webob.exc import HTTPNotFound
 
-from stroller.lib import stroller_url, style_css
+from stroller.lib import stroller_url, style_css, send_email
 from stroller.lib.cart import results, get_cart
 from stroller.model.commerce import *
 from stroller.model.core import DBSession
@@ -48,6 +48,12 @@ class StrollerController(TGController):
         return results(front_categories=front_categories,
                         featured=featured, favourites=favourites,
                         category=category)
+
+    @expose('stroller.templates.featured')
+    def featured(self):
+        featured = DBSession.query(Product).filter_by(featured=True).all()            
+        style_css.inject()
+        return results( featured=featured)
         
     @expose('stroller.templates.category')
     def category(self, uid=None):
@@ -102,19 +108,27 @@ class StrollerController(TGController):
        
         
     @expose(content_type='image/jpeg')
-    def product_thumb(self, uid=None):
-        product = DBSession.query(Product).filter_by(uid=uid).first()
-        if not uid:
+    def product_thumb(self, uid=None, photo='main'):
+        if photo == 'main':
+            product = DBSession.query(Product).filter_by(uid=uid).first()
+        else:
+            product = DBSession.query(ProductPhoto).filter_by(uid=photo).first()
+
+        if not product:
             raise HTTPNotFound()
         
         return product.thumb
         
     @expose(content_type='image/jpeg')
-    def product_image(self, uid=None):
-        product = DBSession.query(Product).filter_by(uid=uid).first()
-        if not uid:
+    def product_image(self, uid=None, photo='main'):
+        if photo == 'main':
+            product = DBSession.query(Product).filter_by(uid=uid).first()
+        else:
+            product = DBSession.query(ProductPhoto).filter_by(uid=photo).first()
+
+        if not product:
             raise HTTPNotFound()
-        
+
         return product.photo
         
     @expose('json')
@@ -138,5 +152,14 @@ class StrollerController(TGController):
             flash(_('Payment successfully registered.'))
             order.dispatched = True
         if not order.payed:
-             flash(_('Order registered but not payed, Please provide your order id either by telephone or fax to proceed with payment. Order ID: %s') % order.uid)
+            stroller_order_mail = config.get('stroller_order_notify_mail', None)
+            if not stroller_order_mail:
+                flash(_('Order registered but not payed, Please provide your order id either by telephone or fax to proceed with payment. Order ID: %s') % order.uid)
+            else:
+                stroller_email_sender = config.get('stroller_email_sender', stroller_order_mail)
+                customer = request.identity and unicode(request.identity['user']) or 'anonymous'
+                customer_email = request.identity and request.identity['user'].email_address or 'anonymous'
+                send_email(stroller_email_sender, stroller_order_mail, '{0} placed an order'.format(customer), 
+                           '''{0} placed order {1}'''.format(customer_email, stroller_url('/manage/show_order', qualified=True, uid=order.uid))) 
+                flash(_('Order registered, you will be contacted back by the site manager to confirm it'))
         return redirect(stroller_url('/'))
