@@ -97,6 +97,12 @@ class EditOrderFields(twf.TableForm):
         shcountry = twf.TextField(label_text="Ship Country")
 edit_order_form = EditOrderFields(submit_text="Edit")
 
+class PhotoForm(twf.TableForm):
+    class fields(WidgetsList):
+        product = twf.HiddenField(validator=validators.Int(not_empty=True))        
+        photo = twf.FileField(label_text="Photo", validator=validators.FieldStorageUploadConverter())
+add_photo_form = PhotoForm(submit_text="Upload")        
+
 def thumbnail(what, size=(128,128)):
     thumb_data = StringIO()
 
@@ -176,9 +182,13 @@ class ManageController(TGController):
         
         del product_data['sprox_id']
         product_data['category'] = Category.by_id(kw['category'])
-        product_data['thumb'] = thumbnail(product_data['photo'].file)
-        product_data['photo'].file.seek(0)
-        product_data['photo'] = productimage(product_data['photo'].file)
+        try:
+            product_data['thumb'] = thumbnail(product_data['photo'].file)
+            product_data['photo'].file.seek(0)
+            product_data['photo'] = productimage(product_data['photo'].file)
+        except:
+            product_data['thumb'] = ''
+            product_data['photo'] = ''
         
         product_info = {}
         product_info['name'] = kw['name']
@@ -197,9 +207,38 @@ class ManageController(TGController):
         
         return redirect(stroller_url('/category', uid=kw['category'].uid))
         
+    @expose('stroller.templates.manage.form')
+    def add_product_photo(self, **kw):
+        manage_css.inject()
+        return dict(form=add_photo_form,
+                    title="Add Photo",
+                    values=kw,
+                    action=stroller_url('/manage/do_add_product_photo'))
+   
+    @expose()
+    @validate(add_photo_form, error_handler=add_product_photo)
+    def do_add_product_photo(self, **kw):
+        kw['product'] = DBSession.query(Product).get(kw['product'])
+        try:
+            kw['thumb'] = thumbnail(kw['photo'].file)
+            kw['photo'].file.seek(0)
+            kw['photo'] = productimage(kw['photo'].file)
+        except:
+            kw['thumb'] = ''
+            kw['photo'] = ''
 
-    
-    
+        DBSession.add(ProductPhoto(**kw))
+        return redirect(stroller_url('/product', uid=kw['product'].uid))
+
+    @expose()
+    def del_product_photo(self, **kw):
+        product = DBSession.query(Product).filter_by(uid=kw.get('product')).first()
+        photo = DBSession.query(ProductPhoto).filter_by(uid=kw.get('photo')).first()
+        if photo:
+            DBSession.delete(photo)
+        flash(_('Photo removed'))
+        return redirect(stroller_url('/product', uid=product.uid))
+ 
     @expose('stroller.templates.manage.form')
     def clone_product(self, op, **kw):
         manage_css.inject()
