@@ -10,7 +10,7 @@ from datetime import datetime
 from stroller.model.commerce import *
 from stroller.model.core import DBSession
 
-__all__ = ['Product', 'ProductInfo', 'Category', 'Order', 'OrderItem']
+__all__ = ['Product', 'ProductInfo', 'Category', 'Order', 'OrderItem', 'ProductPhoto']
 
 class ProductInfo(DeclarativeBase):
     __tablename__ = 'stroller_product_info'
@@ -22,7 +22,17 @@ class ProductInfo(DeclarativeBase):
     
     product_uid = Column(Integer, ForeignKey('stroller_product.uid'))
     product = relation('Product', backref=backref('info', cascade='all, delete-orphan'))
- 
+
+class ProductPhoto(DeclarativeBase):
+    __tablename__ = 'stroller_product_photos'
+
+    uid = Column(Integer, autoincrement=True, primary_key=True)
+    photo = Column(Binary(1024*1024), nullable=False)
+    thumb = Column(Binary(255*1024), nullable=False)
+
+    product_uid = Column(Integer, ForeignKey('stroller_product.uid'))
+    product = relation('Product', backref=backref('photos', cascade='all, delete-orphan'))
+
 class Product(DeclarativeBase):
     __tablename__ = 'stroller_product'
 
@@ -126,7 +136,6 @@ class Category(DeclarativeBase):
                stroller_group in user.groups:
                 return True
 
-            print has_group, user.groups, self.uid
             if not has_group:
                 return True
             
